@@ -6,6 +6,9 @@ from sqlglot.optimizer.schema import ensure_schema
 from sqlglot.optimizer.scope import traverse_scope
 
 
+SKIP_QUALIFY = (exp.Unnest, exp.Lateral)
+
+
 def qualify_columns(expression, schema):
     """
     Rewrite sqlglot AST to have fully qualified columns.
@@ -26,28 +29,18 @@ def qualify_columns(expression, schema):
     schema = ensure_schema(schema)
 
     for scope in traverse_scope(expression):
-        _check_union_outputs(scope)
         _pop_table_column_aliases(scope.ctes)
         _pop_table_column_aliases(scope.derived_tables)
+        _expand_using(scope, schema)
         _qualify_columns(scope, schema)
-        _expand_stars(scope, schema)
-        _qualify_outputs(scope)
+        if not isinstance(scope.expression, SKIP_QUALIFY):
+            _expand_stars(scope, schema)
+            _qualify_outputs(scope)
         _check_unknown_tables(scope)
 
     return expression
 
 
-def _check_union_outputs(scope):
-    """Assert that the outputs of both sides of a UNION are the same"""
-    if not isinstance(scope.expression, exp.Union):
-        return
-    left, right = scope.union
-    if left.expression.named_selects != right.expression.named_selects:
-        raise OptimizeError(
-            f"UNION outputs not equal: {left.expression.named_selects} vs. {right.expression.named_selects}"
-        )
-
-
 def _pop_table_column_aliases(derived_tables):
     """
     Remove table column aliases.
@@ -55,11 +48,52 @@ def _pop_table_column_aliases(derived_tables):
     (e.g. SELECT ... FROM (SELECT ...) AS foo(col1, col2)
     """
     for derived_table in derived_tables:
+        if isinstance(derived_table, SKIP_QUALIFY):
+            continue
         table_alias = derived_table.args.get("alias")
         if table_alias:
             table_alias.args.pop("columns", None)
 
 
+def _expand_using(scope, schema):
+    for join in scope.expression.find_all(exp.Join):
+        using = join.args.get("using")
+
+        if not using:
+            continue
+
+        join_table = join.this.alias_or_name
+
+        source_columns = {
+            k: _get_source_columns(k, scope.sources, schema)
+            for k in scope.selected_sources
+            if join_table != k
+        }
+        join_columns = _get_source_columns(join_table, scope.sources, schema)
+
+        columns = _get_unambiguous_columns(source_columns)
+        conditions = []
+
+        for identifier in using:
+            identifier = identifier.name
+            table = columns.get(identifier)
+
+            if not table or identifier not in join_columns:
+                raise OptimizeError(f"Cannot automatically join: {identifier}")
+
+            conditions.append(
+                exp.condition(
+                    exp.EQ(
+                        this=exp.column(identifier, table=table),
+                        expression=exp.column(identifier, table=join_table),
+                    )
+                )
+            )
+
+        join.args.pop("using")
+        join.set("on", exp.and_(*conditions))
+
+
 def _qualify_columns(scope, schema):
     """Disambiguate columns, ensuring each column specifies a source"""
     unambiguous_columns = None  # lazily loaded
@@ -155,7 +189,6 @@ def _add_replace_columns(expression, tables, replace_columns):
 
 def _qualify_outputs(scope):
     """Ensure all output columns are aliased"""
-
     new_selections = []
 
     for i, (selection, aliased_column) in enumerate(
