@@ -29,6 +29,7 @@ class Parser:
 
     NO_PAREN_FUNCTIONS = {
         TokenType.CURRENT_DATE: exp.CurrentDate,
+        TokenType.CURRENT_DATETIME: exp.CurrentDate,
         TokenType.CURRENT_TIMESTAMP: exp.CurrentTimestamp,
     }
 
@@ -47,6 +48,7 @@ class Parser:
         TokenType.JSON,
         TokenType.TIMESTAMP,
         TokenType.TIMESTAMPTZ,
+        TokenType.DATETIME,
         TokenType.DATE,
         TokenType.ARRAY,
         TokenType.DECIMAL,
@@ -98,6 +100,7 @@ class Parser:
         TokenType.SCHEMA_COMMENT,
         TokenType.SET,
         TokenType.SHOW,
+        TokenType.TABLE,
         TokenType.TABLE_SAMPLE,
         TokenType.TEMPORARY,
         TokenType.TOP,
@@ -125,6 +128,7 @@ class Parser:
         TokenType.LEFT,
         TokenType.RIGHT,
         TokenType.DATE,
+        TokenType.DATETIME,
         TokenType.TIMESTAMP,
         TokenType.TIMESTAMPTZ,
         *CASTS,
@@ -222,12 +226,14 @@ class Parser:
         "sql",
         "errors",
         "index_offset",
+        "unnest_column_only",
         "_tokens",
         "_chunks",
         "_index",
         "_curr",
         "_next",
         "_prev",
+        "_return_subquery",
     )
 
     def __init__(
@@ -235,10 +241,12 @@ class Parser:
         error_level=None,
         error_message_context=100,
         index_offset=0,
+        unnest_column_only=False,
     ):
         self.error_level = error_level or ErrorLevel.RAISE
         self.error_message_context = error_message_context
         self.index_offset = index_offset
+        self.unnest_column_only = unnest_column_only
         self.reset()
 
     def reset(self):
@@ -250,6 +258,7 @@ class Parser:
         self._curr = None
         self._next = None
         self._prev = None
+        self._return_subquery = False
 
     def parse(self, raw_tokens, sql=None):
         """
@@ -415,8 +424,13 @@ class Parser:
                 expression=self._parse_string(),
             )
 
+        # the initial expression may be a subquery so we want to override the default
+        # behavior of returning a Paren object.
+        self._return_subquery = True
+        expression = self._parse_expression()
+        self._return_subquery = False
         return (
-            self._parse_set_operations(self._parse_expression()) or self._parse_with()
+            self._parse_set_operations(expression) if expression else self._parse_with()
         )
 
     def _parse_drop(self):
@@ -525,15 +539,15 @@ class Parser:
             value = self._parse_schema() or self._parse_bracket(self._parse_field())
 
             if schema and not isinstance(value, exp.Schema):
-                columns = {v.text("this").upper() for v in value.args["expressions"]}
+                columns = {v.text("this").upper() for v in value.expressions}
                 partitions = [
                     expression
-                    for expression in schema.args["expressions"]
+                    for expression in schema.expressions
                     if expression.this.text("this").upper() in columns
                 ]
                 schema.set(
                     "expressions",
-                    [e for e in schema.args["expressions"] if e not in partitions],
+                    [e for e in schema.expressions if e not in partitions],
                 )
                 value = self.expression(exp.Schema, expressions=partitions)
         else:
@@ -553,6 +567,15 @@ class Parser:
             properties.extend(self._parse_csv(lambda: self._parse_property(schema)))
             self._match_r_paren()
         else:
+            if self._match(TokenType.USING):
+                properties.append(
+                    self.expression(
+                        exp.Property,
+                        this=exp.Literal.string(c.TABLE_FORMAT),
+                        value=exp.Literal.string(self._parse_var().name),
+                    )
+                )
+
             if self._match_by(TokenType.PARTITION):
                 properties.append(
                     self.expression(
@@ -567,7 +590,7 @@ class Parser:
                 properties.append(
                     self.expression(
                         exp.Property,
-                        this=exp.Literal.string(c.FORMAT),
+                        this=exp.Literal.string(c.FILE_FORMAT),
                         value=exp.Literal.string(self._parse_var().text("this")),
                     )
                 )
@@ -770,11 +793,7 @@ class Parser:
         if self._match(TokenType.L_PAREN):
             this = self._parse_table()
             self._match_r_paren()
-            this = self.expression(
-                exp.Subquery,
-                this=this,
-                alias=self._parse_table_alias(),
-            )
+            this = self._parse_subquery(this)
 
         if self._match(TokenType.SELECT):
             hint = self._parse_hint()
@@ -798,6 +817,8 @@ class Parser:
                     "laterals": self._parse_laterals(),
                     "joins": self._parse_joins(),
                     "where": self._parse_where(),
+                    "window": self._match(TokenType.WINDOW)
+                    and self._parse_window(self._parse_id_var(), alias=True),
                     "group": self._parse_group(),
                     "having": self._parse_having(),
                     "qualify": self._parse_qualify(),
@@ -809,6 +830,16 @@ class Parser:
 
         return self._parse_set_operations(this)
 
+    def _parse_subquery(self, this):
+        return self.expression(
+            exp.Subquery,
+            this=this,
+            alias=self._parse_table_alias(),
+            order=self._parse_order(),
+            limit=self._parse_limit(),
+            offset=self._parse_offset(),
+        )
+
     def _parse_annotation(self, expression):
         if self._match(TokenType.ANNOTATION):
             return self.expression(
@@ -842,20 +873,20 @@ class Parser:
             self.raise_error("Expected VIEW after LATERAL")
 
         outer = self._match(TokenType.OUTER)
-        this = self._parse_function()
-        table = self._parse_id_var()
-        columns = (
-            self._parse_csv(self._parse_id_var)
-            if self._match(TokenType.ALIAS)
-            else None
-        )
 
         return self.expression(
             exp.Lateral,
-            this=this,
+            this=self._parse_function(),
             outer=outer,
-            table=self.expression(exp.Table, this=table),
-            columns=columns,
+            alias=self.expression(
+                exp.TableAlias,
+                this=self._parse_id_var(any_token=False),
+                columns=(
+                    self._parse_csv(self._parse_id_var)
+                    if self._match(TokenType.ALIAS)
+                    else None
+                ),
+            ),
         )
 
     def _parse_joins(self):
@@ -931,25 +962,24 @@ class Parser:
         expressions = self._parse_csv(self._parse_column)
         self._match_r_paren()
 
-        ordinality = self._match(TokenType.WITH) and self._match(TokenType.ORDINALITY)
-        table = self._parse_id_var(self._match(TokenType.ALIAS))
+        ordinality = bool(
+            self._match(TokenType.WITH) and self._match(TokenType.ORDINALITY)
+        )
 
-        if not self._match(TokenType.L_PAREN):
-            return self.expression(
-                exp.Unnest, expressions=expressions, ordinality=ordinality, table=table
-            )
+        alias = self._parse_table_alias()
 
-        columns = self._parse_csv(self._parse_id_var)
-        unnest = self.expression(
+        if alias and self.unnest_column_only:
+            if alias.args.get("columns"):
+                self.raise_error("Unexpected extra column alias in unnest.")
+            alias.set("columns", [alias.this])
+            alias.set("this", None)
+
+        return self.expression(
             exp.Unnest,
             expressions=expressions,
-            ordinality=bool(ordinality),
-            table=table,
-            columns=columns,
+            ordinality=ordinality,
+            alias=alias,
         )
-        self._match_r_paren()
-
-        return unnest
 
     def _parse_table_sample(self, this):
         if not self._match(TokenType.TABLE_SAMPLE):
@@ -1024,7 +1054,7 @@ class Parser:
         )
 
     def _parse_ordered(self):
-        this = self._parse_bitwise()
+        this = self._parse_conjunction()
         self._match(TokenType.ASC)
         return self.expression(exp.Ordered, this=this, desc=self._match(TokenType.DESC))
 
@@ -1108,9 +1138,9 @@ class Parser:
 
             self._match_r_paren()
         elif self._match(TokenType.BETWEEN):
-            low = self._parse_term()
+            low = self._parse_bitwise()
             self._match(TokenType.AND)
-            high = self._parse_term()
+            high = self._parse_bitwise()
             this = self.expression(exp.Between, this=this, low=low, high=high)
 
         if negate:
@@ -1266,6 +1296,8 @@ class Parser:
         if self._match(TokenType.L_PAREN):
             this = self._parse_conjunction() or self._parse_with()
             self._match_r_paren()
+            if self._return_subquery and isinstance(this, exp.Subqueryable):
+                return self._parse_subquery(this)
             return self.expression(exp.Paren, this=this)
 
         return None
@@ -1496,7 +1528,7 @@ class Parser:
 
         return self.expression(exp.Cast if strict else exp.TryCast, this=this, to=to)
 
-    def _parse_window(self, this):
+    def _parse_window(self, this, alias=False):
         if self._match(TokenType.FILTER):
             self._match_l_paren()
             this = self.expression(
@@ -1514,12 +1546,25 @@ class Parser:
             self._match_r_paren()
             return this
 
-        if not self._match(TokenType.OVER):
+        # bigquery select from window x AS (partition by ...)
+        if alias:
+            self._match(TokenType.ALIAS)
+        elif not self._match(TokenType.OVER):
             return this
 
-        self._match_l_paren()
+        if not self._match(TokenType.L_PAREN):
+            alias = self._parse_id_var(False)
+
+            return self.expression(
+                exp.Window,
+                this=this,
+                alias=alias,
+            )
+
         partition = None
 
+        alias = self._parse_id_var(False)
+
         if self._match_by(TokenType.PARTITION):
             partition = self._parse_csv(self._parse_type)
 
@@ -1546,7 +1591,12 @@ class Parser:
         self._match_r_paren()
 
         return self.expression(
-            exp.Window, this=this, partition_by=partition, order=order, spec=spec
+            exp.Window,
+            this=this,
+            partition_by=partition,
+            order=order,
+            spec=spec,
+            alias=alias,
         )
 
     def _parse_window_spec(self):
