@@ -68,6 +68,7 @@ class TokenType(AutoName):
     JSON = auto()
     TIMESTAMP = auto()
     TIMESTAMPTZ = auto()
+    DATETIME = auto()
     DATE = auto()
     UUID = auto()
 
@@ -99,6 +100,7 @@ class TokenType(AutoName):
     CREATE = auto()
     CROSS = auto()
     CURRENT_DATE = auto()
+    CURRENT_DATETIME = auto()
     CURRENT_ROW = auto()
     CURRENT_TIMESTAMP = auto()
     DIV = auto()
@@ -193,6 +195,7 @@ class TokenType(AutoName):
     VIEW = auto()
     WHEN = auto()
     WHERE = auto()
+    WINDOW = auto()
     WITH = auto()
     WITH_TIME_ZONE = auto()
     WITHIN_GROUP = auto()
@@ -454,6 +457,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "TIMESTAMP": TokenType.TIMESTAMP,
         "TIMESTAMPTZ": TokenType.TIMESTAMPTZ,
         "DATE": TokenType.DATE,
+        "DATETIME": TokenType.DATETIME,
     }
 
     WHITE_SPACE = {
